from setuptools import setup, find_packages

setup(
  name='sosAl231',
  version='0.1.1',
  author='feeland',
  author_email='prokuronov.valera@mail.ru',
  description='This is the simplest modu2le for quick work with files.',
  long_description='ss',
  packages=find_packages(),
  keywords='files speedfiles2 ',
  python_requires='>=3.6'
)